import { requestGetFetch } from "@/utils/fetch";
import { getServerSession, Session } from "next-auth";
import { nextauthOptions } from "../nextauth-options";
import { SearchParams } from "@/types/searchParams";

export async function getLocations(searchParams?: SearchParams) {
  try {
    const session: Session = await getServerSession(nextauthOptions);
    const token = session?.user.token;

    // Dynamically build the query string from searchParams
    const paramsArray = searchParams && Object.entries(searchParams);
    const queryString = paramsArray
      ? paramsArray
          .map(([key, value]) =>
            Array.isArray(value)
              ? `${key}=${value.join(",")}` // Use .join(",") without encoding commas
              : `${key}=${String(value)}` // Encode only non-array values
          )
          .join("&")
      : "";

    const path = 'v1/locations' + `${queryString ? `?${queryString}` : ''}`;

    const response = await requestGetFetch({
      path,
      options: {
        headers: {
          Authorization: `Bearer ${token}`,
          "Content-Type": "application/json",
          Accept: "application/json",
        },
        cache: "no-store",
      },
    });
    return response.data || [];
  } catch (error) {
    throw error;
  }
}
